@@ -143,9 +143,7 @@ class ft_connector:
 				reply.raise_for_status()
 			except requests.exceptions.HTTPError as err:
 				print(self.RED + '[42 CONNECTOR] ' + str(err) + " on GET " + endpoint + self.DEFAULT)
-				print(reply)
-				self.put_in_file(json.loads(reply.text), name='error.json')
-				return (json.loads(reply.text))
+				return
 			if 'X-Page' in reply.headers :
 				sum_dict += json.loads(reply.text)
 				if int(reply.headers['X-Page']) * int(reply.headers['X-Per-Page']) >= int(reply.headers['X-Total']):
@@ -169,7 +167,7 @@ class ft_connector:
 				print(self.GREEN + "[42 CONNECTOR] Success POST on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), name='error.json')
-			print(self.RED + '[42 CONNECTOR] ' + str(err) + 'on POST ' + url + self.DEFAULT)
+			print(self.RED + '[42 CONNECTOR] ' + str(err) + ' on POST ' + url + self.DEFAULT)
 
 #######################################################
 # Patch de la data sur un url en fonction du body donné
@@ -183,7 +181,7 @@ class ft_connector:
 				print(self.GREEN + "[42 CONNECTOR] Success PATCH on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), name='error.json')
-			print(self.RED + '[42 CONNECTOR] ' + str(err) + 'on PATCH ' + url + self.DEFAULT)
+			print(self.RED + '[42 CONNECTOR] ' + str(err) + ' on PATCH ' + url + self.DEFAULT)
 
 ##############################
 # Delete de la data sur un url
