@@ -81,7 +81,7 @@ class notion_connector:
 		return (ret)
 
 
-	def createDatabase(self, parentId)
+	def createDatabase(self, parentId):
 		url = self.url + '/blocks/' + parentId + '/children'
 		data = {
 			"children": [
@@ -102,6 +102,8 @@ class notion_connector:
 			self.put_in_file(json.loads(reply.text), name='error.json')
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + 'on PATCH ' + url + self.DEFAULT)
 
+	get_status(data):
+		ret = {}
 
 
 
